@@ -60,6 +60,11 @@ func (m *Manager) saveBrightnessInCfg(valueMap map[string]float64) error {
 					}
 
 					if config.UUID == monitor.uuid {
+						other := monitors.GetByUuidAndName(config.UUID, config.Name)
+						if other != nil && other != monitor {
+							// 存在其他的名字和UUID都对应配置的显示器，不要改该配置
+							continue
+						}
 						config.Name = name
 						config.Brightness = v
 					}
@@ -195,8 +200,9 @@ func (m *Manager) setMonitorBrightness(monitor *Monitor, brightnessValue float64
 	}
 
 	isBuiltin := m.isBuiltinMonitor(monitor.Name)
+	edid := encodeEdidBase64(monitor.edid)
 	err := brightness.Set(brightnessValue, temperature, m.getBrightnessSetter(), isBuiltin,
-		monitor.ID, m.xConn)
+		monitor.ID, m.xConn, monitor.uuid, edid)
 	return err
 }
 
