@@ -1,6 +1,7 @@
 package display
 
 import (
+	"context"
 	"encoding/json"
 	"errors"
 	"fmt"
@@ -18,6 +19,7 @@ import (
 
 	"github.com/davecgh/go-spew/spew"
 	"github.com/godbus/dbus"
+	sessiondisplay "github.com/linuxdeepin/go-dbus-factory/com.deepin.daemon.display"
 	sysdisplay "github.com/linuxdeepin/go-dbus-factory/com.deepin.system.display"
 	inputdevices "github.com/linuxdeepin/go-dbus-factory/com.deepin.system.inputdevices"
 	ofdbus "github.com/linuxdeepin/go-dbus-factory/org.freedesktop.dbus"
@@ -66,6 +68,7 @@ const (
 	gsKeyMapOutput   = "map-output"
 	gsKeyRateFilter  = "rate-filter"
 	//gsKeyPrimary     = "primary"
+	gsXSettingsPrimaryName       = "primary-monitor-name"
 	gsKeyCustomMode              = "current-custom-mode"
 	gsKeyColorTemperatureMode    = "color-temperature-mode"
 	gsKeyColorTemperatureManual  = "color-temperature-manual"
@@ -725,7 +728,7 @@ func (m *Manager) updateMonitorsId(options applyOptions) (changed bool) {
 	oldMonitorsId := m.monitorsId
 	monitorMap := m.cloneMonitorMap()
 	newMonitorsId := getConnectedMonitors(monitorMap).getMonitorsId()
-	if newMonitorsId != oldMonitorsId && newMonitorsId.v1 != "" {
+	if newMonitorsId != oldMonitorsId && (newMonitorsId.v1 != "" || _useWayland) {
 		m.monitorsId = newMonitorsId
 		logger.Debugf("monitors id changed, old monitors id: %v, new monitors id: %v", oldMonitorsId.v1, newMonitorsId.v1)
 		m.markClean()
@@ -992,6 +995,45 @@ func (m *Manager) init() {
 		// 没有内建屏,不监听内核信号
 		logger.Info("built-in screen does not exist")
 	}
+
+	go func() {
+		// 每次设置过主屏后，都将此值同步到xsettings
+		bus, _ := dbus.SessionBus()
+		display := sessiondisplay.NewDisplay(bus)
+		sigLoop := dbusutil.NewSignalLoop(bus, 10)
+		sigLoop.Start()
+		display.InitSignalExt(sigLoop, true)
+		err = display.Primary().ConnectChanged(func(hasValue bool, primary string) {
+			if !hasValue {
+				return
+			}
+
+			// 保持主屏数据和xsettings同步
+			for _, key := range m.xSettingsGs.ListKeys() {
+				if gsXSettingsPrimaryName == key {
+					oldPrimary := m.xSettingsGs.GetString(gsXSettingsPrimaryName)
+					if oldPrimary != primary {
+						m.xSettingsGs.SetString(gsXSettingsPrimaryName, primary)
+					}
+					return
+				}
+			}
+		})
+		if err != nil {
+			logger.Warning("connect to `Primary` property changed failed:", err)
+		}
+
+		// 启动后先同步一次
+		for _, key := range m.xSettingsGs.ListKeys() {
+			if gsXSettingsPrimaryName == key {
+				oldPrimary := m.xSettingsGs.GetString(gsXSettingsPrimaryName)
+				if oldPrimary != m.Primary {
+					m.xSettingsGs.SetString(gsXSettingsPrimaryName, m.Primary)
+				}
+				return
+			}
+		}
+	}()
 }
 
 // calcRecommendedScaleFactor 计算推荐的缩放比
@@ -1167,6 +1209,7 @@ func (m *Manager) addMonitor(monitorInfo *MonitorInfo) error {
 	}
 
 	logger.Debug("addMonitor", monitorInfo.Name)
+	monitorInfo.dumpForDebug()
 
 	monitor := &Monitor{
 		service:            m.service,
@@ -2796,12 +2839,14 @@ func (m *Manager) updateScreenSize() {
 	m.PropsMu.Unlock()
 }
 
-func getLspci() (string, error) {
-	cmd := exec.Command("lspci")
+func getLspci(args []string) (string, error) {
+	ctx, cancel := context.WithTimeout(context.Background(), time.Second*5)
+	cmd := exec.CommandContext(ctx, "lspci", args...)
 	cmd.Env = []string{
 		"LC_ALL=C",
 	}
-	out, err := cmd.Output()
+	out, err := cmd.CombinedOutput()
+	cancel()
 	if err != nil {
 		logger.Warning(err)
 		return "", err
@@ -2811,15 +2856,17 @@ func getLspci() (string, error) {
 }
 
 func (m *Manager) detectDrmSupportGamma() (bool, error) {
-	pciInfo, err := getLspci()
+	args := []string{}
+	pciInfo, err := getLspci(args)
 	if err != nil {
 		logger.Warning(err)
 		return false, err
 	}
 	pciInfos := strings.Split(pciInfo, "\n")
+	vgaSupportGamma := false
 	for _, info := range pciInfos {
 		if strings.Contains(info, "VGA") {
-			vgaSupportGamma := true
+			vgaSupportGamma = true
 			for _, drm := range m.unsupportGammaDrmList {
 				lowDrm := strings.ToLower(drm)
 				lowInfo := strings.ToLower(info)
@@ -2833,5 +2880,16 @@ func (m *Manager) detectDrmSupportGamma() (bool, error) {
 			}
 		}
 	}
-	return false, nil
+	if !vgaSupportGamma {
+		args := []string{"-d 1ed5:"}
+		specifiedVendorInfo, err := getLspci(args)
+		if err != nil {
+			logger.Warning(err)
+			return false, err
+		}
+		if specifiedVendorInfo != "" {
+			vgaSupportGamma = true
+		}
+	}
+	return vgaSupportGamma, nil
 }
