@@ -240,6 +240,10 @@ func decodeEdidBase64(edidB64 string) ([]byte, error) {
 	return base64.StdEncoding.DecodeString(edidB64)
 }
 
+func encodeEdidBase64(edid []byte) string {
+	return base64.StdEncoding.EncodeToString(edid)
+}
+
 type KModeInfo struct {
 	Id          int32 `json:"id"`
 	Width       int32 `json:"width"`
@@ -516,14 +520,10 @@ func (mm *kMonitorManager) apply(monitorsId monitorsId, monitorMap map[uint32]*M
 }
 
 func (mm *kMonitorManager) applyByWLOutput(monitorMap map[uint32]*Monitor) error {
-	var disabledMonitors []*Monitor
-	var args []string
+	var args_enable []string
+	var args_disable []string
 	for _, monitor := range monitorMap {
 		trans := int32(randrRotationToTransform(int(monitor.Rotation)))
-		if !monitor.Enabled {
-			disabledMonitors = append(disabledMonitors, monitor)
-			continue
-		}
 		uuid := mm.mig.getUuidById(monitor.ID)
 		if uuid == "" {
 			logger.Warningf("get monitor %d uuid failed", monitor.ID)
@@ -532,19 +532,29 @@ func (mm *kMonitorManager) applyByWLOutput(monitorMap map[uint32]*Monitor) error
 		logger.Debugf("apply name: %q, uuid: %q, enabled: %v, x: %v, y: %v, mode: %+v, trans:%v",
 			monitor.Name, uuid, monitor.Enabled, monitor.X, monitor.Y, monitor.CurrentMode, trans)
 
-		args = append(args, uuid, "1",
-			strconv.Itoa(int(monitor.X)), strconv.Itoa(int(monitor.Y)),
-			strconv.Itoa(int(monitor.CurrentMode.Width)),
-			strconv.Itoa(int(monitor.CurrentMode.Height)),
-			strconv.Itoa(int(monitor.CurrentMode.Rate*1000)),
-			strconv.Itoa(int(trans)))
-	}
+		if !monitor.Enabled {
+			args_disable = append(args_disable, uuid, "0",
+				strconv.Itoa(int(monitor.X)), strconv.Itoa(int(monitor.Y)),
+				strconv.Itoa(int(monitor.CurrentMode.Width)),
+				strconv.Itoa(int(monitor.CurrentMode.Height)),
+				strconv.Itoa(int(monitor.CurrentMode.Rate*1000)),
+				strconv.Itoa(int(trans)))
+		} else {
+			args_enable = append(args_enable, uuid, "1",
+				strconv.Itoa(int(monitor.X)), strconv.Itoa(int(monitor.Y)),
+				strconv.Itoa(int(monitor.CurrentMode.Width)),
+				strconv.Itoa(int(monitor.CurrentMode.Height)),
+				strconv.Itoa(int(monitor.CurrentMode.Rate*1000)),
+				strconv.Itoa(int(trans)))
 
-	if len(args) > 0 {
+		}
+	}
+	
+	if len(args_enable) > 0 {
 		ctx, cancel := context.WithTimeout(context.Background(), time.Second*5)
 		cmdline := exec.CommandContext(ctx, "/usr/bin/dde_wloutput", "set")
-		cmdline.Args = append(cmdline.Args, args...)
-		logger.Info("cmd line args:", cmdline.Args)
+		cmdline.Args = append(cmdline.Args, args_enable...)
+		logger.Info("cmd line args_enable:", cmdline.Args)
 
 		data, err := cmdline.CombinedOutput()
 		cancel()
@@ -556,18 +566,13 @@ func (mm *kMonitorManager) applyByWLOutput(monitorMap map[uint32]*Monitor) error
 		// wait request done
 		//time.Sleep(time.Millisecond * 500)
 	}
-
-	// TODO 为什么 enabled 和 disabled 需要分开？
-	for _, monitor := range disabledMonitors {
-		logger.Debug("-----------Will disable output:", monitor.Name)
+	if len(args_disable) > 0 {
 		ctx, cancel := context.WithTimeout(context.Background(), time.Second*5)
-		uuid := mm.mig.getUuidById(monitor.ID)
-		if uuid == "" {
-			logger.Warningf("get monitor %d uuid failed", monitor.ID)
-			cancel()
-			return fmt.Errorf("get monitor %d uuid failed", monitor.ID)
-		}
-		data, err := exec.CommandContext(ctx, "/usr/bin/dde_wloutput", "set", uuid, "0", "0", "0", "0", "0", "0", "0").CombinedOutput()
+		cmdline := exec.CommandContext(ctx, "/usr/bin/dde_wloutput", "set")
+		cmdline.Args = append(cmdline.Args, args_disable...)
+		logger.Info("cmd line args_disable:", cmdline.Args)
+
+		data, err := cmdline.CombinedOutput()
 		cancel()
 		// ignore timeout signal
 		if err != nil && !strings.Contains(err.Error(), "killed") {
