@@ -43,7 +43,6 @@ import (
 	systemd1 "github.com/linuxdeepin/go-dbus-factory/org.freedesktop.systemd1"
 	gio "github.com/linuxdeepin/go-gir/gio-2.0"
 	"github.com/linuxdeepin/go-lib/appinfo/desktopappinfo"
-	"github.com/linuxdeepin/go-lib/cgroup"
 	"github.com/linuxdeepin/go-lib/dbusutil"
 	"github.com/linuxdeepin/go-lib/keyfile"
 	"github.com/linuxdeepin/go-lib/log"
@@ -53,8 +52,6 @@ import (
 	"github.com/linuxdeepin/go-x11-client/ext/dpms"
 	"github.com/linuxdeepin/startdde/autostop"
 	"github.com/linuxdeepin/startdde/keyring"
-	"github.com/linuxdeepin/startdde/memchecker"
-	"github.com/linuxdeepin/startdde/swapsched"
 	"github.com/linuxdeepin/startdde/watchdog"
 	"github.com/linuxdeepin/startdde/wm_kwin"
 	"github.com/linuxdeepin/startdde/xcursor"
@@ -122,8 +119,11 @@ const (
 	SessionStageAppsEnd
 )
 
-var (
-	swapSchedDispatcher *swapsched.Dispatcher
+const (
+	dpmsStateOn int32 = iota
+	dpmsStateStandBy
+	dpmsStateSuspend
+	dpmsStateOff
 )
 
 func (m *SessionManager) CanLogout() (bool, *dbus.Error) {
@@ -396,11 +396,16 @@ func (m *SessionManager) RequestSuspend() *dbus.Error {
 	// 使用窗管接口进行黑屏处理
 	if _gSettingsConfig.needQuickBlackScreen {
 		logger.Info("request wm blackscreen effect")
-		cmd := exec.Command("/bin/bash", "-c", "dbus-send --print-reply --dest=org.kde.KWin /BlackScreen org.kde.kwin.BlackScreen.setActive boolean:true")
-		error := cmd.Run()
-		if error != nil {
-			logger.Warning("wm blackscreen failed")
+		if _useWayland {
+			setDpmsModeByKwin(dpmsStateOff)
+		} else {
+			cmd := exec.Command("/bin/bash", "-c", "dbus-send --print-reply --dest=org.kde.KWin /BlackScreen org.kde.kwin.BlackScreen.setActive boolean:true")
+			error := cmd.Run()
+			if error != nil {
+				logger.Warning("wm blackscreen failed")
+			}
 		}
+
 	}
 
 	logger.Info("login1 start suspend")
@@ -546,16 +551,6 @@ func (m *SessionManager) getLocked() bool {
 	return v
 }
 
-func callSwapSchedHelperPrepare(sessionID string) error {
-	sysBus, err := dbus.SystemBus()
-	if err != nil {
-		return err
-	}
-	const dest = "com.deepin.daemon.SwapSchedHelper"
-	obj := sysBus.Object(dest, "/com/deepin/daemon/SwapSchedHelper")
-	return obj.Call(dest+".Prepare", 0, sessionID).Store()
-}
-
 func (m *SessionManager) initSession() {
 	var err error
 
@@ -594,78 +589,6 @@ func (m *SessionManager) initSession() {
 			logger.Warning("failed to connect Active changed:", err)
 		}
 	}
-	if _gSettingsConfig.swapSchedEnabled {
-		m.initSwapSched()
-	} else {
-		logger.Info("swap sched disabled")
-	}
-}
-
-func (m *SessionManager) initSwapSched() {
-	err := cgroup.Init()
-	if err != nil {
-		logger.Warning(err)
-		return
-	}
-
-	globalCgExecBin, err = exec.LookPath("cgexec")
-	if err != nil {
-		logger.Warning("cgexec not found:", err)
-		return
-	}
-
-	if m.objLoginSessionSelf == nil {
-		return
-	}
-	sessionID, err := m.objLoginSessionSelf.Id().Get(0)
-	if err != nil {
-		logger.Warning(err)
-	}
-
-	err = callSwapSchedHelperPrepare(sessionID)
-	if err != nil {
-		logger.Warning("call SwapSchedHelper.Prepare error:", err)
-	}
-
-	swapsched.SetLogger(logger)
-
-	memCheckerCfg := memchecker.GetConfig()
-
-	logger.Debugf("mem checker cfg min mem avail: %d KB", memCheckerCfg.MinMemAvail)
-	var enableMemAvailMax int64 // unit is byte
-	enableMemAvailMax = int64(memCheckerCfg.MinMemAvail*1024) - 100*swapsched.MB
-	if enableMemAvailMax < 0 {
-		enableMemAvailMax = 100 * swapsched.MB
-	}
-
-	swapSchedCfg := swapsched.Config{
-		UIAppsCGroup:       sessionID + "@dde/uiapps",
-		DECGroup:           sessionID + "@dde/DE",
-		EnableMemAvailMax:  uint64(enableMemAvailMax),
-		DisableMemAvailMin: uint64(enableMemAvailMax) + 200*swapsched.MB,
-	}
-	swapSchedDispatcher, err = swapsched.NewDispatcher(swapSchedCfg)
-	logger.Debugf("swap sched config: %+v", swapSchedCfg)
-
-	if err == nil {
-		// add self to DE cgroup
-		deCg := cgroup.NewCgroup(swapSchedDispatcher.GetDECGroup())
-		deCg.AddController(cgroup.Memory)
-		err = deCg.AttachCurrentProcess()
-		if err != nil {
-			logger.Warning("failed to add self to DE cgroup:", err)
-		}
-
-		go func() {
-			err = swapsched.ActiveWindowHandler(swapSchedDispatcher.ActiveWindowHandler).Monitor()
-			if err != nil {
-				logger.Warning(err)
-			}
-		}()
-		go swapSchedDispatcher.Balance()
-	} else {
-		logger.Warning("failed to new swap sched dispatcher:", err)
-	}
 }
 
 func newSessionManager(service *dbusutil.Service) *SessionManager {
@@ -1322,9 +1245,9 @@ func setDPMSMode(on bool) {
 	var err error
 	if _useWayland {
 		if !on {
-			_, err = exec.Command("dde_wldpms", "-s", "Off").Output()
+			setDpmsModeByKwin(dpmsStateOff)
 		} else {
-			_, err = exec.Command("dde_wldpms", "-s", "On").Output()
+			setDpmsModeByKwin(dpmsStateOn)
 		}
 	} else {
 		var mode = uint16(dpms.DPMSModeOn)
@@ -1437,3 +1360,32 @@ func getCurSessionPath() (dbus.ObjectPath, error) {
 	}
 	return sessionPath, nil
 }
+
+func setDpmsModeByKwin(mode int32) {
+	logger.Debug("[startdde] Set DPMS State", mode)
+
+	sessionBus, err := dbus.SessionBus()
+	if err != nil {
+		logger.Warning(err)
+		return
+	}
+	sessionObj := sessionBus.Object("com.deepin.daemon.KWayland", "/com/deepin/daemon/KWayland/DpmsManager")
+	var ret []dbus.Variant
+	err = sessionObj.Call("com.deepin.daemon.KWayland.DpmsManager.dpmsList", 0).Store(&ret)
+	if err != nil {
+		logger.Warning(err)
+		return
+	}
+
+	for i := 0; i < len(ret); i++ {
+		v := ret[i].Value().(string)
+		sessionObj := sessionBus.Object("com.deepin.daemon.KWayland", dbus.ObjectPath(v))
+		err = sessionObj.Call("com.deepin.daemon.KWayland.Dpms.setDpmsMode", 0, int32(mode)).Err
+		if err != nil {
+			logger.Warning(err)
+			return
+		}
+	}
+
+	return
+}
